.. _chapter_2_scientific_workflow:

Chapter 2: Scientific Workflow
==============================

This folder will contain chapter 2 of the **HowToFit** lectures, which will explain
how to build a scientific workflow. However, the chapter is not written yet.

The functionality required to develop a scientific workflow is fully supported in autofit and described in the
"Scientific Workflow" overview section on readthedocs.

If you are a confident model-fitting practitioner, you should be able to follow this example to perform the tasks
required to build a scientific workflow.